import * as yup from 'yup';

const jpLocale = {
  mixed: {
    required: '必須の項目です'
  },
  string: {
    email: 'メールアドレス形式である必要があります',
    max: '${max}文字以下で入力してください',
    min: '${min}文字以上で入力してください'
  }
};

yup.setLocale(jpLocale);

const schema = yup.object().shape({
  email: yup.string().email().required(),
  password: yup.string().max(20).min(8).required()
});

const form = document.getElementById('form');
const emailInput =
  document.getElementById('email-input');
const emailError =
  document.getElementById('email-error');
const passwordInput =
  document.getElementById('password-input');
const passwordError =
  document.getElementById('password-error');

form.addEventListener('submit', (e) => { // (d1)
  e.preventDefault();
  schema
    .validate({ // (d2)
      email: emailInput.value,
      password: passwordInput.value
    }, { abortEarly: false })
    .then((data) => {
      console.log(data)
      alert('ログイン処理を実行');
    })
    .catch((error) => {
      if (error instanceof yup.ValidationError) {
        const errors = error.inner
          .reduce((result, err) => { // (d3)
            result[err.path] = err.message;
            return result;
          }, {});
        emailError.textContent =
          errors.email ?? '';
        passwordError.textContent =
          errors.password ?? '';
      } else {
        throw error;
      }
    });
});
