import * as yup from 'yup';

const jpLocale = {
  mixed: {
    required: '必須の項目です'
  },
  string: {
    email: 'メールアドレス形式である必要があります',
    max: '${max}文字以下で入力してください',
    min: '${min}文字以上で入力してください'
  }
};

yup.setLocale(jpLocale);

const schema = yup.object().shape({
  isEmployee: yup.boolean().required(),
  username: yup.string().required(),
  email: yup.string().email()
    .when('isEmployee', {
      is: true,
      then: (schema) => schema.required()
    }),
  password: yup.string().max(20).min(8).required(),
  passwordConfirm: yup.string().test(
    'invalid_password_confirm',
    'パスワードと一致していません',
    (value, context) =>
      value === context.parent.password
  ).required()
});

const form = document.getElementById('form');
const isEmployeeInput =
  document.getElementById('is-employee-input')
const usernameInput =
  document.getElementById('username-input')
const usernameError =
  document.getElementById('username-error')
const emailInput =
  document.getElementById('email-input');
const emailError =
  document.getElementById('email-error');
const passwordInput =
  document.getElementById('password-input');
const passwordError =
  document.getElementById('password-error');
const passwordConfirmInput =
  document.getElementById('password-confirm-input');
const passwordConfirmError =
  document.getElementById('password-confirm-error');

form.addEventListener('submit', (e) => {
  e.preventDefault();

  schema
    .validate({
      isEmployee: isEmployeeInput.checked,
      username: usernameInput.value,
      email: emailInput.value,
      password: passwordInput.value,
      passwordConfirm: passwordConfirmInput.value
    }, { abortEarly: false })
    .then((data) => {
      console.log(data)
      alert('ユーザー登録処理を実行');
    })
    .catch((error) => {
      if (error instanceof yup.ValidationError) {
        const errors = error.inner
          .reduce((result, err) => {
            result[err.path] = err.message;
            return result;
          }, {});
        usernameError.textContent =
          errors.username ?? '';
        emailError.textContent =
          errors.email ?? '';
        passwordError.textContent =
          errors.password ?? '';
        passwordConfirmError.textContent =
          errors.passwordConfirm ?? '';
      } else {
        throw error;
      }
    });
});
