import { useForm } from "react-hook-form";
import { yupResolver } from '@hookform/resolvers/yup';
import * as yup from "yup";

const jpLocale = {
  mixed: {
    required: '必須の項目です'
  },
  string: {
    email: 'メールアドレス形式である必要があります',
    max: '${max}文字以下で入力してください',
    min: '${min}文字以上で入力してください'
  }
};

yup.setLocale(jpLocale);

const schema = yup.object().shape({
  isEmployee: yup.boolean().required(),
  username: yup.string().required(),
  email: yup.string().email().when('isEmployee', {
    is: true,
    then: (schema) => schema.required()
  }),
  password: yup.string().max(20).min(8).required(),
  passwordConfirm: yup.string().test(
    'invalid_password_confirm',
    'パスワードと一致していません',
    (value, context) => value === context.parent.password
  ).required()
});

const RegisterForm = () => {
  const {
    register,
    handleSubmit,
    formState: { errors }
  } = useForm({ // (d1)
    mode: 'onSubmit',
    reValidateMode: 'onSubmit',
    resolver: yupResolver(schema)
  });

  const registerUser = (data) => { // (d2)
    console.log(data);
    alert('ユーザー登録処理を実行');
  };

  return (
    <form onSubmit={handleSubmit(registerUser)}>
      <div>
        <label>
          <input
            type="checkbox"
            {...register('isEmployee') /* (d3) */}
          />
          従業員の場合はチェック
        </label>
      </div>
      <div>
        <label>
          ユーザー名
          <input {...register('username')} />
        </label>
        {/* (d4) */}
        <span>{errors.username?.message}</span>
      </div>
      <div>
        <label>
          メールアドレス
          <input
            type="mail"
            {...register('email')}
          />
        </label>
        <span>{errors.email?.message}</span>
      </div>
      <div>
        <label>
          パスワード
          <input
            type="password"
            {...register('password')}
          />
        </label>
        <span>{errors.password?.message}</span>
      </div>
      <div>
        <label>
          パスワード（確認）
          <input
            type="password"
            {...register('passwordConfirm')}
          />
        </label>
        <span>{errors.passwordConfirm?.message}</span>
      </div>
      <button type="submit">登録</button>
    </form>
  );
};

export default RegisterForm;
